/****************************************************************
 *								*
 * Copyright (c) 2001-2018 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef MUTEX_DEADLOCK_CHECK_INCLUDED
#define MUTEX_DEADLOCK_CHECK_INCLUDED

void mutex_deadlock_check(CRIT_PTR_T addr, sgmnt_addrs *csa);

#endif
